@@ -58,6 +58,7 @@ import Graphics.Rendering.Diagrams.Paths
 import Graphics.Rendering.Diagrams.Engine (sizeAndPos)
 import Control.Arrow (first)
 import Control.Monad.Cont
+import Control.Monad.Identity
 
 import Data.List (transpose)
 import Data.Tree
@@ -409,10 +410,6 @@ tree ls ss (Node d ts) = vsepA ls hcenter [ d, hsep ss (map (tree ls ss) ts) ]
 
 -- Miscellaneous ---------------------------------
 
-newtype Identity a = Identity a
-instance Functor Identity where
-  fmap f (Identity x) = Identity (f x)
-
 data Padded = Padded Double Double HAlignment VAlignment
 instance LayoutClass Padded Identity where
   layoutSizeAndPos (Padded dw dh ha va) (Identity ((w,h), d))
@@ -466,8 +463,9 @@ withSize :: (Double -> Double -> Diagram) -- ^ Function for new diagram
          -> Diagram
 withSize f dia = Compound (Layout (FromSize f) (Identity dia))
 
-diagSize :: Diagram -> Cont Diagram (Double, Double) 
-diagSize d = Cont { runCont = \f -> flip withSize d $ \w h -> f (w, h) } 
+diagSize :: Diagram -> Cont Diagram (Double, Double)
+diagSize d = ContT { runContT = \f -> Identity . flip withSize d $
+                                      \w h -> runIdentity (f (w, h)) }
 
 -- | Align diagrams into a grid, specifying individual alignments for each item.
 --   Warning: there is currently an exponential performace blowup if you nest grids
